==> kdepim4_4.14.10.orig.tar.xz: kdepim-4.14.10/pimsettingexporter/pimsettingexporterkernel.h <==
/*
  Copyright (c) 2012-2015 Montel Laurent <montel@kde.org>

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License, version 2, as
  published by the Free Software Foundation.

  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/
#ifndef PIMSETTINGEXPORTERKERNEL_H
#define PIMSETTINGEXPORTERKERNEL_H

#include <mailcommon/interfaces/mailinterfaces.h>
#include "pimsettingexporter_export.h"
namespace Akonadi {
class EntityTreeModel;
class EntityMimeTypeFilterModel;
}

namespace MailCommon {
class FolderCollectionMonitor;
}

class PIMSETTINGEXPORT_EXPORT PimSettingExporterKernel : public QObject, public MailCommon::IKernel, public MailCommon::ISettings
{
public:
    explicit PimSettingExporterKernel( QObject *parent = 0 );

    KPIMIdentities::IdentityManager *identityManager();
    MessageComposer::MessageSender *msgSender();

    Akonadi::EntityMimeTypeFilterModel *collectionModel() const;
    KSharedConfig::Ptr config();
    void syncConfig();
    MailCommon::JobScheduler* jobScheduler() const;
    Akonadi::ChangeRecorder *folderCollectionMonitor() const;
    void updateSystemTray();

    qreal closeToQuotaThreshold();
    bool excludeImportantMailFromExpiry();
    QStringList customTemplates();
    Akonadi::Entity::Id lastSelectedFolder();
    void setLastSelectedFolder(const Akonadi::Entity::Id& col);
    bool showPopupAfterDnD();

private:
    KPIMIdentities::IdentityManager *mIdentityManager;
    MessageComposer::MessageSender *mMessageSender;
    MailCommon::FolderCollectionMonitor *mFolderCollectionMonitor;
    Akonadi::EntityTreeModel *mEntityTreeModel;
    Akonadi::EntityMimeTypeFilterModel *mCollectionModel;
};

#endif

==> kdepim_4.13.3.orig.tar.xz: kdepim-4.13.3/pimsettingexporter/pimsettingexporterkernel.h <==
/*
  Copyright (c) 2012-2013 Montel Laurent <montel@kde.org>

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License, version 2, as
  published by the Free Software Foundation.

  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/
#ifndef PIMSETTINGEXPORTERKERNEL_H
#define PIMSETTINGEXPORTERKERNEL_H

#include <mailcommon/interfaces/mailinterfaces.h>

namespace Akonadi {
class EntityTreeModel;
class EntityMimeTypeFilterModel;
}

namespace MailCommon {
class FolderCollectionMonitor;
}

class PimSettingExporterKernel : public QObject, public MailCommon::IKernel, public MailCommon::ISettings
{
public:
    explicit PimSettingExporterKernel( QObject *parent = 0 );

    KPIMIdentities::IdentityManager *identityManager();
    MessageComposer::MessageSender *msgSender();

    Akonadi::EntityMimeTypeFilterModel *collectionModel() const;
    KSharedConfig::Ptr config();
    void syncConfig();
    MailCommon::JobScheduler* jobScheduler() const;
    Akonadi::ChangeRecorder *folderCollectionMonitor() const;
    void updateSystemTray();

    qreal closeToQuotaThreshold();
    bool excludeImportantMailFromExpiry();
    QStringList customTemplates();
    Akonadi::Entity::Id lastSelectedFolder();
    void setLastSelectedFolder(const Akonadi::Entity::Id& col);
    bool showPopupAfterDnD();

private:
    KPIMIdentities::IdentityManager *mIdentityManager;
    MessageComposer::MessageSender *mMessageSender;
    MailCommon::FolderCollectionMonitor *mFolderCollectionMonitor;
    Akonadi::EntityTreeModel *mEntityTreeModel;
    Akonadi::EntityMimeTypeFilterModel *mCollectionModel;
};

#endif
